@@ -81,6 +81,8 @@ sub connect_database {
 	my $info;
 	my $olddir = getcwd;
 	my $debug = $ENV{DBDPG_DEBUG} || 0;
+	delete @ENV{ 'PGSERVICE', 'PGDATABASE' };
+
 
 	## We'll try various ways to get to a database to test with
 
@@ -421,6 +423,9 @@ version: $version
 
 		## Attempt to boost the system oids above an int for certain testing
 		(my $resetxlog = $initdb) =~ s/initdb/pg_resetxlog/;
+		if ($version >= 10) {
+			$resetxlog =~ s/pg_resetxlog/pg_resetwal/;
+		}
 		eval {
 			$info = qx{$resetxlog --help};
 		};
